@@ -73,7 +73,7 @@ class Classification:
                                 xgb- XGBoost self.Classifier
                                 ann - Artificial Neural Network
             params : dict
-                        contains self.parameters for model
+                        contains parameters for model
             tune : boolean
                     when True Applies GridSearch CrossValidation
                     Default is False
@@ -253,7 +253,7 @@ class Classification:
             self.classifier_name, accuracy = kfold(
                 self.classifier,
                 self.predictor,
-                self.X_train, self.y_train, self.cv_folds,
+                self.X_train, self.y_train, self.cv_folds,False
             )
 
         # GridSearch ---------------------------------------------------------------------
